@@ -1,90 +1,98 @@
 from .pyutils.version import get_version
-
-from .types import (
-    AbstractType,
-    ObjectType,
-    InputObjectType,
-    Interface,
-    Mutation,
-    Field,
-    InputField,
-    Schema,
-    Scalar,
-    String,
-    ID,
-    Int,
-    Float,
-    Boolean,
-    Date,
-    DateTime,
-    Time,
-    Decimal,
-    JSONString,
-    UUID,
-    List,
-    NonNull,
-    Enum,
-    Argument,
-    Dynamic,
-    Union,
-    Context,
-    ResolveInfo,
-)
 from .relay import (
-    Node,
-    is_node,
-    GlobalID,
+    BaseGlobalIDType,
     ClientIDMutation,
     Connection,
     ConnectionField,
+    DefaultGlobalIDType,
+    GlobalID,
+    Node,
     PageInfo,
+    SimpleGlobalIDType,
+    UUIDGlobalIDType,
+    is_node,
+)
+from .types import (
+    ID,
+    UUID,
+    Argument,
+    Base64,
+    BigInt,
+    Boolean,
+    Context,
+    Date,
+    DateTime,
+    Decimal,
+    Dynamic,
+    Enum,
+    Field,
+    Float,
+    InputField,
+    InputObjectType,
+    Int,
+    Interface,
+    JSONString,
+    List,
+    Mutation,
+    NonNull,
+    ObjectType,
+    ResolveInfo,
+    Scalar,
+    Schema,
+    String,
+    Time,
+    Union,
 )
-from .utils.resolve_only_args import resolve_only_args
 from .utils.module_loading import lazy_import
+from .utils.resolve_only_args import resolve_only_args
 
+VERSION = (3, 2, 0, "final", 0)
 
-VERSION = (2, 1, 7, "final", 0)
 
 __version__ = get_version(VERSION)
 
 __all__ = [
     "__version__",
-    "ObjectType",
-    "InputObjectType",
-    "Interface",
-    "Mutation",
-    "Field",
-    "InputField",
-    "Schema",
-    "Scalar",
-    "String",
-    "ID",
-    "Int",
-    "Float",
-    "Enum",
-    "Boolean",
-    "Date",
-    "DateTime",
-    "Time",
-    "Decimal",
-    "JSONString",
-    "UUID",
-    "List",
-    "NonNull",
     "Argument",
-    "Dynamic",
-    "Union",
-    "resolve_only_args",
-    "Node",
-    "is_node",
-    "GlobalID",
+    "Base64",
+    "BigInt",
+    "BaseGlobalIDType",
+    "Boolean",
     "ClientIDMutation",
     "Connection",
     "ConnectionField",
-    "PageInfo",
-    "lazy_import",
     "Context",
+    "Date",
+    "DateTime",
+    "Decimal",
+    "DefaultGlobalIDType",
+    "Dynamic",
+    "Enum",
+    "Field",
+    "Float",
+    "GlobalID",
+    "ID",
+    "InputField",
+    "InputObjectType",
+    "Int",
+    "Interface",
+    "JSONString",
+    "List",
+    "Mutation",
+    "Node",
+    "NonNull",
+    "ObjectType",
+    "PageInfo",
     "ResolveInfo",
-    # Deprecated
-    "AbstractType",
+    "Scalar",
+    "Schema",
+    "SimpleGlobalIDType",
+    "String",
+    "Time",
+    "Union",
+    "UUID",
+    "UUIDGlobalIDType",
+    "is_node",
+    "lazy_import",
+    "resolve_only_args",
 ]
